<title>Help | Workoutizer</title>

{% extends 'lib/base.html' %}
{% block body %}
    <h3>Help</h3>
    <hr>
    <br>
    <div class="container">

        <h4><b>Source Code</b></h4>
        <p>The Workoutizer source code can be found on:</p>
        <ul>
            <li><a href="https://github.com/fgebhart/workoutizer">https://github.com/fgebhart/workoutizer</a></li>
        </ul>
        <p>Feel free to get in touch to contribute or open an <a
                href="https://github.com/fgebhart/workoutizer/issues">issue</a>.</p>
        <br>
        <br>
        <h4><b>Keyboard Navigation</b></h4>
        {% include "lib/keymap.html" %}
        <br>
        <br>
        <h4><b>Version</b></h4>
        <p>You are running the version: <span class="badge badge-secondary">{{ version }}</span></p>
        <p>Have a look at the <a href="https://github.com/fgebhart/workoutizer/releases">release page</a>
            for the recent releases.</p>
    </div>
{% endblock %}
