<p>Use the following keyboard shortcuts to navigate through Workoutizer:</p>
<div class="form-group row">
    <div class="col-sm-3"><u>G</u>o to <u>D</u>ashboard</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>d</kbd></div>
    <div class="col-sm-3"><u>G</u>o to all <u>S</u>ports</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>s</kbd></div>
    <div class="col-sm-3"><u>G</u>o to add Activity</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>n</kbd></div>
    <div class="col-sm-3"><u>G</u>o to <u>A</u>wards</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>a</kbd></div>
    <div class="col-sm-3"><u>G</u>o to Sport</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>Number</kbd></div>
    <div class="col-sm-3"><u>G</u>o to Settings</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>,</kbd></div>
    <div class="col-sm-3"><u>G</u>o to <u>H</u>elp</div><div class="col-sm-9"><kbd>g</kbd> + <kbd>h</kbd></div>
    <div class="col-sm-3">Toggle Sidebar</div><div class="col-sm-9"><kbd>[</kbd></div>
</div>