body {
    font-family: 'Ubuntu', sans-serif;
}

.btn-space {
    margin-right: 5px;
}

.leaflet-container {
    height: 500px;
}

#id_path_to_trace_dir {
    width: 70%;
}

#id_gpx_checker_interval {
    width: 10%;
}

#id_duration {
    width: 10%;
}

#id_distance {
    width: 10%;
}

#id_description {
    width: 70%;
}

#id_title {
    width: 70%;
}

.dropdown-menu {
    min-width: inherit;
}

.table td.limit {
    max-width: 350px;
}

.table td.limit span {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    display: inline-block;
    max-width: 100%;
}

.sidebar_right {
    width: 300px;
    float: right;
    position: fixed;
    right: 0;
    top: 0;
    border-style: solid;
    border-color: rgba(0, 0, 0, 0.1);
    border-width: thin;
    background-color: whitesmoke;
    padding-top: 75px;
    height: 100%;
    transition: right 0.5s ease-out;
}

.sidebar_left .closebtn {
    width: 200px;
}

.sidebar_left a:hover {
    color: #f1f1f1;
}

.sidebar_left {
    position: fixed;
    width: 45px;
    background-color: whitesmoke;
    overflow-x: hidden;
    height: 100%;
    transition: 1s;
    top: 55px;
    border-style: solid;
    border-color: rgba(0, 0, 0, 0.1);
    border-width: thin;
}

#main {
    transition: 1s;
    overflow-x: hidden;
    padding: 30px;
    margin-left: 40px;
    margin-top: 45px
}

#open-sidebar {
    position: absolute;
    top: 0;
    right: -32px;
    display: none;
}

.container-fluid > div{
    position: relative;
}

@media only screen and (max-width: 992px) {
    .content_left {
        max-width: none;
        flex: none;
    }

    .sidebar_right {
        max-width: none;
        position: fixed;
        width: 300px;
        top: 0;
        /*left: 100%;*/
        right: -300px;
        overflow-x: hidden;
    }

    .sidebar_opened {
        /*left: auto;*/
        right: 0;
    }

    #open-sidebar {
        display: block;
    }
}