{% csrf_token %}
{{ form.media }}
{% include "lib/form_errors.html" %}
{% include "lib/messages.html" %}
<div class="form-group row">
    <div class="col-sm-3">{{ form.name.label }}</div>
    <div class="col-sm-9">{{ form.name }}</div>
</div>
<div class="form-group row">
    <div class="col-sm-3">{{ form.icon.label }}</div>
    <div class="col-sm-9">{{ form.icon }}&nbsp;&nbsp;(name of <a href="https://fontawesome.com/">font awesome</a> icon)
    </div>
</div>
<div class="form-group row">
    <div class="col-sm-3">{{ form.color.label }}</div>
    <div class="col-sm-3">{{ form.color }}</div>
</div>
<div class="form-group row">
    <div class="col-sm-3">{{ form.evaluates_for_awards.label }}</div>
    <div class="col-sm-9">{{ form.evaluates_for_awards }}&nbsp;&nbsp;
        <i class="fas fa-question" data-toggle="tooltip" data-placement="right"
           title="When enabled {{ sport.name }} activities will be considered for awards."></i>
    </div>
</div>
<br>
